<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="用户姓名" prop="userName">
        <el-input
          v-model="queryParams.userName"
          placeholder="请输入用户姓名"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="预约日期" prop="orderTime">
        <el-date-picker clearable
          v-model="queryParams.orderTime"
          type="date"
          value-format="yyyy-MM-dd"
          placeholder="请选择预约日期">
        </el-date-picker>
      </el-form-item>
      <el-form-item label="教练名字" prop="coachName">
        <el-input
          v-model="queryParams.coachName"
          placeholder="请输入教练名字"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="reservationCourseList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column
        type="index"
        width="50">
      </el-table-column>
      <el-table-column label="用户姓名" align="center" prop="userName" />
      <el-table-column label="用户手机号" align="center" prop="sysUser.phonenumber" />
      <el-table-column label="预约日期" align="center" prop="orderTime" width="180">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.orderTime, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>
      <el-table-column label="时间段" align="center" prop="timePeriod" />
<!--      <el-table-column label="教练名字" align="center" prop="coachName" />-->
      <el-table-column label="教练" align="center" prop="coachName" >
<!--        <template #default="data">-->
<!--          <el-select @change="changeCoachName(data.row)" v-model="data.row.coachName" placeholder="请选择">-->
<!--            <el-option-->
<!--              v-for="item in jlListAll"-->
<!--              :key="item.instructorName"-->
<!--              :label="item.instructorName"-->
<!--              :value="item.instructorName">-->
<!--            </el-option>-->
<!--          </el-select>-->
<!--        </template>-->
      </el-table-column>
<!--      <el-table-column label="科目类型" align="center" prop="accountType" />-->
<!--      <el-table-column label="科目类型" align="center" >-->
<!--        <template #default="data">-->
<!--          <div v-if="data.row.accountType.includes('2') ">科目二</div>-->
<!--          <div v-if="data.row.accountType.includes('3') ">科目三</div>-->
<!--          <div v-if="data.row.accountType.includes('5') ">科目五</div>-->
<!--        </template>-->
<!--      </el-table-column>-->
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
<!--          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
          >修改</el-button>-->
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改预约练车对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="600px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="120px">
        <el-form-item label="用户姓名" prop="userName">
          <el-input v-model="form.userName" placeholder="请输入用户姓名" />
        </el-form-item>
        <el-form-item label="预约日期" prop="orderTime">
          <el-date-picker clearable
            v-model="form.orderTime"
            type="date"
            value-format="yyyy-MM-dd"
            placeholder="请选择预约日期">
          </el-date-picker>
        </el-form-item>
        <el-form-item label="时间段" prop="timePeriod">
<!--          <el-input v-model="form.timePeriod" placeholder="请输入时间段 1：上午 2：下午" />-->
          <el-select v-model="form.timePeriod" placeholder="请选择">
            <el-option
              v-for="item in timePeriod"
              :key="item"
              :label="item"
              :value="item">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="教练名字" prop="coachName">
          <el-input v-model="form.coachName" placeholder="请输入教练名字" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listReservationCourse, getReservationCourse, delReservationCourse, addReservationCourse,
  updateReservationCourse, findJlListAll, updateCourseById } from "./api/reservationCourse";

export default {
  name: "ReservationCourse",
  data() {
    return {

      timePeriod: ["上午", "下午"],

      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 预约练车表格数据
      reservationCourseList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,

      jlListAll: [],
      jlName: null,

      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        deptId: null,
        userId: null,
        userName: null,
        orderTime: null,
        timePeriod: null,
        coachId: null,
        coachName: null,
        accountType: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
      }
    };
  },
  created() {
    this.getList();
    this.changeFindJlListAll()
  },
  methods: {
    changeCoachName(data) {
      console.log("方法被调用了", data)
      updateCourseById(data)
    },
    changeFindJlListAll() {
      findJlListAll().then(item => {
        this.jlListAll = item.rows
        console.log("获取到的数据为 ===========>", this.jlListAll)
      })
    },

    /** 查询预约练车列表 */
    getList() {
      this.loading = true;
      listReservationCourse(this.queryParams).then(response => {
        this.reservationCourseList = response.data.records;
        this.total = response.data.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        deptId: null,
        userId: null,
        userName: null,
        orderTime: null,
        timePeriod: null,
        coachId: null,
        coachName: null,
        accountType: null,
        createTime: null,
        createBy: null,
        updateTime: null,
        updateBy: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加预约练车";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getReservationCourse(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改预约练车";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateReservationCourse(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addReservationCourse(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除预约练车编号为"' + ids + '"的数据项？').then(function() {
        return delReservationCourse(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('drivingSchool/system/reservationCourse/export', {
        ...this.queryParams
      }, `reservationCourse_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
